#include <QtWidgets>

#include "mainwindow.h"

//! [0]
MainWindow::MainWindow()
{
    QWidget *widget = new QWidget;
    setCentralWidget(widget);
//! [0]

//! [1]
    QWidget *topFiller = new QWidget;
    topFiller->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);

//    infoLabel = new QLabel(tr("<i>Choose a menu option, or right-click to "
//                              "invoke a context menu</i>"));
//    infoLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
//    infoLabel->setAlignment(Qt::AlignCenter);

    QWidget *bottomFiller = new QWidget;
    bottomFiller->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);

    model=new XmlModel(this);
    treeView=new QTreeView(this);
    treeView->setModel(model);
    treeView->setContextMenuPolicy(Qt::ContextMenuPolicy());

    QVBoxLayout *layout = new QVBoxLayout;
    layout->setContentsMargins(5, 5, 5, 5);
    layout->addWidget(topFiller);
    //layout->addWidget(infoLabel);
    layout->addWidget(bottomFiller);
    layout->addWidget(treeView);
    widget->setLayout(layout);
//! [1]

//! [2]
    createActions();
    createMenus();

    QString message = tr("A context menu is available by right-clicking");
    statusBar()->showMessage(message);

    setWindowTitle(tr("Menus"));
    setMinimumSize(160, 160);
    resize(480, 320);
}
//! [2]

//! [3]
#ifndef QT_NO_CONTEXTMENU
void MainWindow::contextMenuEvent(QContextMenuEvent *event)
{
    QMenu menu(this);
    menu.addAction(makeActiveAct);
    menu.exec(event->globalPos());
}
#endif // QT_NO_CONTEXTMENU

void MainWindow::open()
{
    QStringList FilesName=QFileDialog::getOpenFileNames(this,"Открыть XML-файл(-ы)","D:","XML-файл(*.xml)");
    model->addFiles(FilesName);
    treeView->reset(); //Reset the internal state of the view.
}

void MainWindow::close()
{
    delete model;
    model=new XmlModel(this);
    treeView->setModel(model);
    treeView->reset();
}

void MainWindow::makeActive()
{
//    infoLabel->setText(tr("Invoked <b>Edit|Cut</b>"));
}

void MainWindow::createActions()
{

    openAct = new QAction(tr("&Open..."), this);
    openAct->setShortcuts(QKeySequence::Open);
    openAct->setStatusTip(tr("Open an existing file"));
    connect(openAct, &QAction::triggered, this, &MainWindow::open);
//! [5]

    closeAct = new QAction(tr("&Close all"), this);
    closeAct->setShortcuts(QKeySequence::Close);
    closeAct->setStatusTip(tr("Close all documents"));
    connect(closeAct, &QAction::triggered, this, &MainWindow::close);

    exitAct = new QAction(tr("E&xit"), this);
    exitAct->setShortcuts(QKeySequence::Quit);
    exitAct->setStatusTip(tr("Exit the application"));
    connect(exitAct, &QAction::triggered, this, &QWidget::close);

    makeActiveAct = new QAction(tr("Make Active"), this);
    makeActiveAct->setStatusTip(tr("Make active the current selection's contents"));
    connect(makeActiveAct, &QAction::triggered, this, &MainWindow::makeActive);
}
//! [7]

//! [8]
void MainWindow::createMenus()
{
//! [9] //! [10]
    fileMenu = menuBar()->addMenu(tr("&File"));
    fileMenu->addAction(openAct);
    fileMenu->addAction(closeAct);
    fileMenu->addSeparator();
    fileMenu->addAction(exitAct);
}
//! [12]

